as.jury.point: Calculates probability a jury will find defendant guilty...

View source: R/as.jury.point.r

as.jury.pointR Documentation

Calculates probability a jury will find defendant guilty based on juror preferences

Description

Calculates the probability that a jury of size jury_n finds defendant guilty given preferences of the jury pool (input as sample_pg). Does not estimate uncertainty (use as.jury.stats function for inferential statistics).

Usage

as.jury.point(
  sample_pg,
  jury_n = 12,
  pstrikes = 0,
  dstrikes = 0,
  accuracy = 0.15,
  simulate = FALSE
)

Arguments

sample_pg

Proportion of jurors who favor a guilty verdict. Can be a single number between 0 and 1, or a vector of such numbers.

jury_n

Size of the jury (i.e. 6, 8, or 12); default value is 12.

pstrikes

Number of peremptory strikes by prosecution; default value is 0.

dstrikes

Number of peremptory strikes by defendant; default value is 0.

accuracy

Accuracy of parties' peremptory strikes; a number between 0 and 1; default value is .15.

simulate

Simulation control. Use 'FALSE' (default) for deterministic Markov model values, 'TRUE' for simulation with defaults ('nDraws=10000', 'seed=NULL'), or a named list like 'list(nDraws=5000, seed=12345)'.

Value

Returns the probability jury finds defendant guilty (if sample_pg is a single number) or vector of such probabilities (if sample_pg is a vector).

Examples

   library(sate)
   as.jury.point(sample_pg = .50)

   as.jury.point(sample_pg = 10/12)

   as.jury.point(sample_pg = .50, simulate = TRUE)

sate documentation built on March 6, 2026, 1:07 a.m.

Related to as.jury.point in sate...