View source: R/as.jury.stats.r
| as.jury.stats | R Documentation |
Calculates probability jury finds defendant guilty based on verdicts preferences of jury pool. Also reports standard error and confidence interval of estimate (use as.jury.point function for estimate only).
as.jury.stats(
sample_pg,
sample_n,
jury_n = 12,
pstrikes = 0,
dstrikes = 0,
accuracy = 0.15,
digits = 3,
simulate = FALSE
)
sample_pg |
Proportion of jurors who favor a guilty verdict; a number between 0 and 1. |
sample_n |
Size of sample used to estimate sample_pg. |
jury_n |
Size of the jury (i.e. 6, 8, or 12); default value is 12. |
pstrikes |
Number of peremptory strikes by prosecution; default value is 0. |
dstrikes |
Number of peremptory strikes by defendant; default value is 0. |
accuracy |
Accuracy of parties' peremptory strikes; a number between 0 and 1; default value is .15. |
digits |
Number of digits to report after decimal places; default value is 3. |
simulate |
Simulation control for uncertainty estimation. Use 'FALSE' (default) for analytic method, 'TRUE' for simulation with defaults ('nDraws=10000', 'seed=NULL'), or a named list like 'list(nDraws=5000, seed=12345)'. |
Returns a one-row data.frame with columns: P(G), SE, MOE, Lower 5
library(sate)
as.jury.stats(sample_pg=.50, sample_n=830)
as.jury.stats(sample_pg=10/12, sample_n=295)
as.jury.stats(sample_pg=.50, sample_n=830, simulate=TRUE)
as.jury.stats(sample_pg=.50, sample_n=830,
simulate=list(nDraws=5000, seed=12345))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.