basic.plot.grid: Creates the shell of a plot showing relationship between jury...

View source: R/basic.plot.grid.R

basic.plot.gridR Documentation

Creates the shell of a plot showing relationship between jury pool preferences and jury verdict probabilities

Description

Creates the shell of a plot showing relationship between jury pool preferences and jury verdict probabilities, optional argument to modify main, xlab, and ylab labels, includes grid lines.

Usage

basic.plot.grid(main, xlab, ylab)

Arguments

main

Main title for plot (optional), default is no main title.

xlab

X-axis label for plot (optional), default is "Jurors' Verdict Preferences, P(g)".

ylab

Y-axis label for plot (optional), default is "Jury Verdict Probabilities, P(G)".

Value

No return value; function creates a plot.

Examples

   library(sate)
   basic.plot.grid()

   basic.plot.grid(main="Death Sentencing Analysis", xlab="Jurors' Sentencing Preferences, P(d)",
                   ylab="Jury Verdict Probabilities, P(D)")

sate documentation built on March 6, 2026, 1:07 a.m.

Related to basic.plot.grid in sate...