compact_harm_plot: Creates the shell of a plot used to display estimate of harm...

View source: R/helper.functions.r

compact_harm_plotR Documentation

Creates the shell of a plot used to display estimate of harm relative to harm threshold

Description

Creates the shell of a plot used for compact display estimate of harm estimate relative to harm thresholds.

Usage

compact_harm_plot()

Value

No return

Examples

   library(sate)
   compact_harm_plot()

sate documentation built on March 6, 2026, 1:07 a.m.

Related to compact_harm_plot in sate...