get_pG_by_k: Calculates vector of probabilities that jury with jury_n will...

View source: R/get_pG_by_k.r

get_pG_by_kR Documentation

Calculates vector of probabilities that jury with jury_n will return a guilty verdict

Description

Calculates a vector of probabilities that a jury with jury_n will return a guilty verdict. The vector represents P(G|k) for 0, 1, 2, ... , jury_n where k is the number of jurors initially in favor of guilty verdict.

Usage

get_pG_by_k(jury_n = 6)

Arguments

jury_n

Size of the jury (i.e. 6, 8, or 12); default value is 6.

Value

Returns a vector of probabilities for guilty verdict of size jury_n + 1.

Examples

   library(sate)
   get_pG_by_k(10)

   get_pG_by_k(jury_n=12)

sate documentation built on March 6, 2026, 1:07 a.m.

Related to get_pG_by_k in sate...