graph.effect.defendant: Plots jury-level differences based on juror-level statistics...

View source: R/graph.effect.defendant.r

graph.effect.defendantR Documentation

Plots jury-level differences based on juror-level statistics with effect-on-defendant displayed

Description

Plots jury-level differences based on juror-level statistics supplied by user. Point estimates supplemented by confidence intervals. Effect-on-defendant also plotted.

Usage

graph.effect.defendant(
  pg_actual,
  n_actual,
  pg_hypo,
  n_hypo,
  jury_n = 12,
  pstrikes = 0,
  dstrikes = 0,
  accuracy = 0.15,
  simulate = FALSE
)

Arguments

pg_actual

The proportion of jurors who favor a guilty verdict in the actual trial condition (the trial with error).

n_actual

The size of the sample used to estimate pg_actual.

pg_hypo

The proportion of jurors who favor a guilty verdict in the hypothetical trial condition (the fair trial without error).

n_hypo

The size of the sample used to estimate pg_hypo.

jury_n

Size of the jury (i.e. 6, 8, or 12); default value is 12.

pstrikes

Number of peremptory strikes by prosecution; default value is 0.

dstrikes

Number of peremptory strikes by defendant; default value is 0.

accuracy

Accuracy of parties' peremptory strikes; a number between 0 and 1; default value is .15.

simulate

Simulation control passed to 'compare.jury.stats' and 'as.jury.stats'. Use 'FALSE' (default), 'TRUE', or a named list like 'list(nDraws=5000, seed=12345)'. For graphing speed, 'TRUE' uses 'nDraws=2000' by default.

Value

No return (creates plots)

Examples

   library(sate)
   graph.effect.defendant(pg_actual=.70, n_actual=400, pg_hypo=.60, n_hypo=450)

   graph.effect.defendant(pg_actual=.75, n_actual=450, pg_hypo=.65, n_hypo=350,
                         jury_n=6, pstrikes=3, dstrikes=3)

   graph.effect.defendant(pg_actual=.70, n_actual=400, pg_hypo=.60, n_hypo=450, simulate=TRUE)

sate documentation built on March 6, 2026, 1:07 a.m.