graph.estimate: Plots probability of a guilty verdict with confidence...

View source: R/graph.estimate.r

graph.estimateR Documentation

Plots probability of a guilty verdict with confidence interval based on juror-level statistics

Description

Plots probability of guilty verdict with confidence interval based on juror-level statistics supplied by user. Similar to graph.effect.defendant, but plots one condition.

Usage

graph.estimate(
  sample_pg,
  sample_n,
  jury_n = 12,
  pstrikes = 0,
  dstrikes = 0,
  accuracy = 0.15,
  simulate = FALSE
)

Arguments

sample_pg

The proportion of jurors who favor a guilty verdict in the sample condition

sample_n

The size of the sample used to estimate sample_pg_actual

jury_n

Size of the jury (i.e. 6, 8, or 12); default value is 12.

pstrikes

Number of peremptory strikes by prosecution; default value is 0.

dstrikes

Number of peremptory strikes by defendant; default value is 0.

accuracy

Accuracy of parties' peremptory strikes; a number between 0 and 1; default value is .15.

simulate

Simulation control passed to 'as.jury.stats'. Use 'FALSE' (default), 'TRUE', or a named list like 'list(nDraws=5000, seed=12345)'. For graphing speed, 'TRUE' uses 'nDraws=2000' by default.

Value

No return (creates plot)

Examples

   library(sate)
   graph.estimate(sample_pg=.70, sample_n=400)

   graph.estimate(sample_pg=.75, sample_n=450, jury_n=6, pstrikes=3, dstrikes=3)

   graph.estimate(sample_pg=.70, sample_n=400, simulate=TRUE)

sate documentation built on March 6, 2026, 1:07 a.m.

Related to graph.estimate in sate...