prob_ord_from_pool: verdict probabilities based on jury pool sentiment for...

View source: R/prob_ord_from_pool.R

prob_ord_from_poolR Documentation

verdict probabilities based on jury pool sentiment for ordered verdict options.

Description

verdict probabilities based on jury pool sentiment for ordered verdict options.

Usage

prob_ord_from_pool(jury_n, verdict_options, verdict_props, digits = NULL)

Arguments

jury_n

Integer. Number of jurors.

verdict_options

Character vector of ordered verdict labels (e.g., 'c("NG","M2","M1")'). Order matters: left = most lenient. Labels must be non-missing, non-empty, and unique.

verdict_props

Numeric vector specifying proportion of jurors who support the respective verdict_options in the population from which jurors are drawn. (e.g., 'c(.25,.50,.25)'). Must correspond to verdict_options, contain non-missing finite values, be non-negative, and sum to a positive value.

digits

Integer. Optional, number of digits to round in the returned matrix.

Value

A vector of length K that are probabilities of the ordered verdicts.

See Also

[transition.matrix.ordered]

Examples

library(sate)

# Three-verdict ordered model with a 12-person jury:
prob_ord_from_pool(12, c("NG", "M2", "M1"), c(.25,.50,.25), digits=3)


sate documentation built on March 6, 2026, 1:07 a.m.