sim.as.jury.stats: Estimates jury-level probability of guilty verdict based on...

View source: R/sim.as.jury.stats.r

sim.as.jury.statsR Documentation

Estimates jury-level probability of guilty verdict based on juror-level statistics based on empirical data

Description

Returns estimate of the probability of guilty verdict based on juror-level statistics supplied by user. Also reports inferential statistics. Results are based on an empirical model with greater uncertainty than as.jury.stats function.

Usage

sim.as.jury.stats(
  sample_pg,
  sample_n,
  jury_n = 12,
  pstrikes = 0,
  dstrikes = 0,
  accuracy = 0.15,
  digits = 3,
  nDraws = 10000,
  seed = NULL
)

Arguments

sample_pg

The proportion of jurors who favor a guilty verdict in the jury pool

sample_n

The size of the sample used to estimate sample_pg

jury_n

Size of the jury (i.e. 6, 8, or 12); default value is 12.

pstrikes

Number of peremptory strikes by prosecution; default value is 0.

dstrikes

Number of peremptory strikes by defendant; default value is 0.

accuracy

Accuracy of parties' peremptory strikes; a number between 0 and 1; default value is .15.

digits

Number of digits to report after decimal places; default value is 3.

nDraws

The number of simulations used to generate results. Should be very large number (default = 10000).

seed

Optional non-negative integer seed for replication. Default is NULL (no seeding).

Value

Returns a one-row data.frame with columns: P(G), SE, MOE, Lower 5

Examples

   library(sate)
   sim.as.jury.stats(sample_pg=.50, sample_n=830, nDraws=500)

   sim.as.jury.stats(sample_pg=10/12, sample_n=295, pstrikes=6, dstrikes=10, nDraws=1000)

sate documentation built on March 6, 2026, 1:07 a.m.

Related to sim.as.jury.stats in sate...