sim.compare.jury.stats: Estimates jury-level differences based on juror-level...

View source: R/sim.compare.jury.stats.r

sim.compare.jury.statsR Documentation

Estimates jury-level differences based on juror-level statistics using simulations based on empirical data

Description

Calculates jury-level differences based on juror-level statistics supplied by user. Results based on empirical data, inferential statistics produced via simulations.

Usage

sim.compare.jury.stats(
  pg_actual,
  n_actual,
  pg_hypo,
  n_hypo,
  jury_n = 12,
  digits = 3,
  pstrikes = 0,
  dstrikes = 0,
  accuracy = 0.15,
  seed = NULL,
  nDraws = 10000
)

Arguments

pg_actual

The proportion of jurors who favor a guilty verdict in the actual trial condition (the trial with error).

n_actual

The size of the sample used to estimate pg_actual.

pg_hypo

The proportion of jurors who favor a guilty verdict in the hypothetical trial condition (the fair trial without error).

n_hypo

The size of the sample used to estimate pg_hypo.

jury_n

Size of the jury (i.e. 6, 8, or 12); default value is 12.

digits

Number of digits to report after decimal places; default value is 3.

pstrikes

Number of peremptory strikes by prosecution; default value is 0.

dstrikes

Number of peremptory strikes by defendant; default value is 0.

accuracy

Accuracy of parties' peremptory strikes; a number between 0 and 1; default value is .15.

seed

Optional non-negative integer seed for replication. Default is NULL (no seeding).

nDraws

The number of simulations used to generate results. Should be very large number (default = 10000).

Value

Returns a list of jury-level statistics to assess effect of a trial error.

Examples

   library(sate)
   sim.compare.jury.stats(pg_actual=.70, n_actual=400, pg_hypo=.60, n_hypo=450, nDraws=500)

   sim.compare.jury.stats(pg_actual=.75, n_actual=450, pg_hypo=.65, n_hypo=350,
                      seed=12345, nDraws=1000)

sate documentation built on March 6, 2026, 1:07 a.m.