View source: R/transition.matrix.R
| transition.matrix | R Documentation |
Returns a (jury_n + 1) by (jury_n + 1) matrix of probabilities. Columns represent current state and rows represent next state. Column values sum to 1. Depending on use, you may want to transpose rows and columns.
transition.matrix(jury_n)
jury_n |
The number of jurors. |
A matrix of transition probabilities.
library(sate)
transition.matrix(6)
transition.matrix(jury_n=12)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.