View source: R/prob_ord_from_pool.R
| prob_ord_from_pool | R Documentation |
verdict probabilities based on jury pool sentiment for ordered verdict options.
prob_ord_from_pool(jury_n, verdict_options, verdict_props, digits = NULL)
jury_n |
Integer. Number of jurors. |
verdict_options |
Character vector of ordered verdict labels (e.g., 'c("NG","M2","M1")'). Order matters: left = most lenient. Labels must be non-missing, non-empty, and unique. |
verdict_props |
Numeric vector specifying proportion of jurors who support the respective verdict_options in the population from which jurors are drawn. (e.g., 'c(.25,.50,.25)'). Must correspond to verdict_options, contain non-missing finite values, be non-negative, and sum to a positive value. |
digits |
Integer. Optional, number of digits to round in the returned matrix. |
A vector of length K that are probabilities of the ordered verdicts.
[transition.matrix.ordered]
library(sate)
# Three-verdict ordered model with a 12-person jury:
prob_ord_from_pool(12, c("NG", "M2", "M1"), c(.25,.50,.25), digits=3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.